==> react-map-basic-1.52.0.tgz: package/lib/leaflet/marker-manager.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import L from 'leaflet';

var MarkerManager = /*#__PURE__*/function () {
  function MarkerManager(mapDOMInstance) {
    var _this = this;

    this.isPoiClicked = function (evt) {
      var _evt$target = evt.target,
          propertyInfo = _evt$target.propertyInfo,
          markerType = _evt$target.markerType;

      if (markerType === 0) {
        return;
      }

      _this.dispatchCustomEvent({
        eventName: 'leaflet_map_poiclick',
        detail: _extends({}, propertyInfo, {
          markerType: markerType
        })
      });
    };

    this.setMapDOMInstance(mapDOMInstance);
    this.setMarkerDefaults();
    this.POPUP_WAIT_TIME = 1000;
  }

  var _proto = MarkerManager.prototype;

  _proto.setMapDOMInstance = function setMapDOMInstance(mapDOMInstance) {
    this.mapDOM = mapDOMInstance;
  };

  _proto.dispatchCustomEvent = function dispatchCustomEvent(_ref) {
    var eventName = _ref.eventName,
        detail = _ref.detail;
    var event;

    if (this.mapDOM.CustomEvent && typeof this.mapDOM.CustomEvent === 'function') {
      event = new this.mapDOM.CustomEvent(eventName, {
        detail: detail
      });
    } else {
      event = document.createEvent('CustomEvent');
      event.initCustomEvent(eventName, true, true, detail);
    }

    this.mapDOM.dispatchEvent(event);
  };

  _proto.createMarker = function createMarker(item) {
    var _this2 = this;

    var events = [{
      eventName: 'add',
      eventHandler: function eventHandler(_ref2) {
        var target = _ref2.target;
        return target._icon.id = target.Id;
      }
    }, {
      eventName: 'click',
      eventHandler: function eventHandler(e) {
        return _this2.isPoiClicked(e);
      }
    }, {
      eventName: 'dragend',
      eventHandler: function eventHandler(e) {
        return _this2.onPoiDragEnd(e);
      }
    }, {
      eventName: 'mouseover',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseOver(e);
      }
    }, {
      eventName: 'mouseout',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseOut(e);
      }
    }, {
      eventName: 'mousemove',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseMove(e);
      }
    }];
    var isDraggable = item.isDraggable,
        latitude = item.latitude,
        longitude = item.longitude,
        markerType = item.markerType,
        _item$propertyInfo = item.propertyInfo,
        propertyInfo = _item$propertyInfo === void 0 ? {} : _item$propertyInfo;
    var marker = L.marker([latitude, longitude], {
      icon: this.getIconFor({
        item: item
      }),
      draggable: isDraggable
    });
    marker.propertyInfo = propertyInfo;
    marker.markerType = markerType;
    marker.Id = propertyInfo.propertyId;
    marker.latlon = latitude + ',' + longitude;
    events.map(function (event) {
      return marker.on(event.eventName, event.eventHandler);
    });
    return marker;
  };

  _proto.onPoiDragEnd = function onPoiDragEnd(evt) {
    var _evt$target2 = evt.target,
        propertyInfo = _evt$target2.propertyInfo,
        markerType = _evt$target2.markerType,
        latlng = _evt$target2._latlng;

    if (markerType === 0) {
      return;
    }

    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poidragend',
      detail: _extends({}, propertyInfo, {
        latlng: latlng
      })
    });
  };

  _proto.onMouseOver = function onMouseOver(evt) {
    var _evt$target3 = evt.target,
        propertyInfo = _evt$target3.propertyInfo,
        markerType = _evt$target3.markerType;

    if (markerType === 0) {
      return;
    }

    var originalEvent = evt.originalEvent;
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimouseover',
      detail: _extends({}, propertyInfo, {
        originalEvent: originalEvent
      })
    });
  };

  _proto.onMouseMove = function onMouseMove(evt) {
    var _evt$target4 = evt.target,
        propertyInfo = _evt$target4.propertyInfo,
        markerType = _evt$target4.markerType;

    if (markerType === 0) {
      return;
    }

    var originalEvent = evt.originalEvent;
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimousemove',
      detail: _extends({}, propertyInfo, {
        originalEvent: originalEvent
      })
    });
  };

  _proto.onMouseOut = function onMouseOut(evt) {
    var markerType = evt.target.markerType;

    if (markerType === 0) {
      return;
    }

    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimouseout'
    });
  };

  _proto.setMarkerDefaults = function setMarkerDefaults() {
    this.markerTypeEquivalences = ['minipoi', 'poi', 'label'];
    this.DEFAULT_MARKER_TYPE = 'minipoi';
  };

  _proto.resetMarkerType = function resetMarkerType(markerType) {
    this._markerType = markerType;
  };

  _proto.addIconMarkersToMap = function addIconMarkersToMap(_ref3) {
    var _this3 = this;

    var _ref3$icons = _ref3.icons,
        icons = _ref3$icons === void 0 ? [] : _ref3$icons,
        map = _ref3.map;
    icons.forEach(function (icon) {
      var iconInstance = L.icon({
        iconUrl: icon.iconUrl,
        iconSize: icon.size,
        iconAnchor: icon.anchor,
        shadowUrl: icon.shadowUrl
      });
      var marker = L.marker([icon.lat, icon.lng], {
        icon: iconInstance
      }).addTo(map);

      if (icon.popup) {
        var content = icon.popup.content; // wait some time in order to get the correct position for the popup

        setTimeout(function () {
          marker.bindPopup(content).openPopup();
        }, _this3.POPUP_WAIT_TIME);
      }
    });
  };

  _proto.getIconFor = function getIconFor(_ref4) {
    var item = _ref4.item;
    var customClassName = item.customClassName,
        propertyInfo = item.propertyInfo;
    var price = propertyInfo.price;
    var className = this.getInitialIcon();
    var priceText = '';
    var extendedIconClassName = className;

    if (className !== this.DEFAULT_MARKER_TYPE) {
      if (className === 'label') {
        priceText = price;
      }

      extendedIconClassName += ' ' + className;
      extendedIconClassName += ' ' + customClassName;
    }

    className = extendedIconClassName;
    return this.getDivIconFor({
      className: className,
      html: priceText
    });
  };

  _proto.getDivIconFor = function getDivIconFor(_ref5) {
    var className = _ref5.className,
        html = _ref5.html;
    return new L.DivIcon({
      className: className,
      html: html,
      iconSize: null
    });
  };

  _proto.getInitialIcon = function getInitialIcon() {
    return this.markerTypeEquivalences[this._markerType] || this.DEFAULT_MARKER_TYPE;
  };

  return MarkerManager;
}();

export default MarkerManager;

==> react-map-basic-1.55.0.tgz: package/lib/leaflet/marker-manager.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import L from 'leaflet';
var MarkerManager = /*#__PURE__*/function () {
  function MarkerManager(mapDOMInstance) {
    var _this = this;
    this.isPoiClicked = function (evt) {
      var _evt$target = evt.target,
        propertyInfo = _evt$target.propertyInfo,
        markerType = _evt$target.markerType;
      if (markerType === 0) {
        return;
      }
      _this.dispatchCustomEvent({
        eventName: 'leaflet_map_poiclick',
        detail: _extends({}, propertyInfo, {
          markerType: markerType
        })
      });
    };
    this.setMapDOMInstance(mapDOMInstance);
    this.setMarkerDefaults();
    this.POPUP_WAIT_TIME = 1000;
  }
  var _proto = MarkerManager.prototype;
  _proto.setMapDOMInstance = function setMapDOMInstance(mapDOMInstance) {
    this.mapDOM = mapDOMInstance;
  };
  _proto.dispatchCustomEvent = function dispatchCustomEvent(_ref) {
    var eventName = _ref.eventName,
      detail = _ref.detail;
    var event;
    if (this.mapDOM.CustomEvent && typeof this.mapDOM.CustomEvent === 'function') {
      event = new this.mapDOM.CustomEvent(eventName, {
        detail: detail
      });
    } else {
      event = document.createEvent('CustomEvent');
      event.initCustomEvent(eventName, true, true, detail);
    }
    this.mapDOM.dispatchEvent(event);
  };
  _proto.createMarker = function createMarker(item) {
    var _this2 = this;
    var events = [{
      eventName: 'add',
      eventHandler: function eventHandler(_ref2) {
        var target = _ref2.target;
        return target._icon.id = target.Id;
      }
    }, {
      eventName: 'click',
      eventHandler: function eventHandler(e) {
        return _this2.isPoiClicked(e);
      }
    }, {
      eventName: 'dragend',
      eventHandler: function eventHandler(e) {
        return _this2.onPoiDragEnd(e);
      }
    }, {
      eventName: 'mouseover',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseOver(e);
      }
    }, {
      eventName: 'mouseout',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseOut(e);
      }
    }, {
      eventName: 'mousemove',
      eventHandler: function eventHandler(e) {
        return _this2.onMouseMove(e);
      }
    }];
    var isDraggable = item.isDraggable,
      latitude = item.latitude,
      longitude = item.longitude,
      markerType = item.markerType,
      _item$propertyInfo = item.propertyInfo,
      propertyInfo = _item$propertyInfo === void 0 ? {} : _item$propertyInfo;
    var marker = L.marker([latitude, longitude], {
      icon: this.getIconFor({
        item: item
      }),
      draggable: isDraggable
    });
    marker.propertyInfo = propertyInfo;
    marker.markerType = markerType;
    marker.Id = propertyInfo.propertyId;
    marker.latlon = latitude + ',' + longitude;
    events.map(function (event) {
      return marker.on(event.eventName, event.eventHandler);
    });
    return marker;
  };
  _proto.onPoiDragEnd = function onPoiDragEnd(evt) {
    var _evt$target2 = evt.target,
      propertyInfo = _evt$target2.propertyInfo,
      markerType = _evt$target2.markerType,
      latlng = _evt$target2._latlng;
    if (markerType === 0) {
      return;
    }
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poidragend',
      detail: _extends({}, propertyInfo, {
        latlng: latlng
      })
    });
  };
  _proto.onMouseOver = function onMouseOver(evt) {
    var _evt$target3 = evt.target,
      propertyInfo = _evt$target3.propertyInfo,
      markerType = _evt$target3.markerType;
    if (markerType === 0) {
      return;
    }
    var originalEvent = evt.originalEvent;
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimouseover',
      detail: _extends({}, propertyInfo, {
        originalEvent: originalEvent
      })
    });
  };
  _proto.onMouseMove = function onMouseMove(evt) {
    var _evt$target4 = evt.target,
      propertyInfo = _evt$target4.propertyInfo,
      markerType = _evt$target4.markerType;
    if (markerType === 0) {
      return;
    }
    var originalEvent = evt.originalEvent;
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimousemove',
      detail: _extends({}, propertyInfo, {
        originalEvent: originalEvent
      })
    });
  };
  _proto.onMouseOut = function onMouseOut(evt) {
    var markerType = evt.target.markerType;
    if (markerType === 0) {
      return;
    }
    this.dispatchCustomEvent({
      eventName: 'leaflet_map_poimouseout'
    });
  };
  _proto.setMarkerDefaults = function setMarkerDefaults() {
    this.markerTypeEquivalences = ['minipoi', 'poi', 'label'];
    this.DEFAULT_MARKER_TYPE = 'minipoi';
  };
  _proto.resetMarkerType = function resetMarkerType(markerType) {
    this._markerType = markerType;
  };
  _proto.addIconMarkersToMap = function addIconMarkersToMap(_ref3) {
    var _this3 = this;
    var _ref3$icons = _ref3.icons,
      icons = _ref3$icons === void 0 ? [] : _ref3$icons,
      map = _ref3.map;
    icons.forEach(function (icon) {
      var iconInstance = L.icon({
        iconUrl: icon.iconUrl,
        iconSize: icon.size,
        iconAnchor: icon.anchor,
        shadowUrl: icon.shadowUrl
      });
      var marker = L.marker([icon.lat, icon.lng], {
        icon: iconInstance
      }).addTo(map);
      if (icon.popup) {
        var content = icon.popup.content;
        // wait some time in order to get the correct position for the popup
        setTimeout(function () {
          marker.bindPopup(content).openPopup();
        }, _this3.POPUP_WAIT_TIME);
      }
    });
  };
  _proto.getIconFor = function getIconFor(_ref4) {
    var item = _ref4.item;
    var customClassName = item.customClassName,
      propertyInfo = item.propertyInfo;
    var price = propertyInfo.price;
    var className = this.getInitialIcon();
    var priceText = '';
    var extendedIconClassName = className;
    if (className !== this.DEFAULT_MARKER_TYPE) {
      if (className === 'label') {
        priceText = price;
      }
      extendedIconClassName += ' ' + className;
      extendedIconClassName += ' ' + customClassName;
    }
    className = extendedIconClassName;
    return this.getDivIconFor({
      className: className,
      html: priceText
    });
  };
  _proto.getDivIconFor = function getDivIconFor(_ref5) {
    var className = _ref5.className,
      html = _ref5.html;
    return new L.DivIcon({
      className: className,
      html: html,
      iconSize: null
    });
  };
  _proto.getInitialIcon = function getInitialIcon() {
    return this.markerTypeEquivalences[this._markerType] || this.DEFAULT_MARKER_TYPE;
  };
  return MarkerManager;
}();
export default MarkerManager;
